DeclarativeList<T extends Object> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DeclarativeList
Constructors
-
DeclarativeList({required List<
T> items, required AnimatedItemBuilder<T> itemBuilder, required AnimatedItemBuilder<T> removeBuilder, EqualityCheck<T> ? equalityCheck, Axis scrollDirection = Axis.vertical, Duration? insertDuration, Duration? removeDuration, ScrollController? scrollController, EdgeInsetsGeometry? padding, ScrollPhysics? physics, bool? primary, bool reverse = false, bool shrinkWrap = false, Clip clipBehavior = Clip.hardEdge, Key? key}) -
const
Properties
- clipBehavior → Clip
-
Refer to
AnimatedList.clipBehaviorfinal -
equalityCheck
→ EqualityCheck<
T> ? -
Callback that is used to determine if two given objects are equal. ==
operator will be used by default.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialItemCount → int
-
Initial items count for the list, gets defined automatically
final
- insertDuration → Duration?
-
Refer to
AnimatedListState.insertItemfinal -
itemBuilder
→ AnimatedItemBuilder<
T> -
Builder function for inserted items
final
-
items
→ List<
T> -
Set of items to be displayed in the list
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsetsGeometry?
-
Refer to
AnimatedList.paddingfinal - physics → ScrollPhysics?
-
Refer to
AnimatedList.physicsfinal - primary → bool?
-
Refer to
AnimatedList.primaryfinal -
removeBuilder
→ AnimatedItemBuilder<
T> -
Builder function for removed items
final
- removeDuration → Duration?
-
Refer to
AnimatedListState.removeItemfinal - reverse → bool
-
Refer to
AnimatedList.reversefinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
Refer to
AnimatedList.controllerfinal - scrollDirection → Axis
-
Refer to
AnimatedList.scrollDirectionfinal - shrinkWrap → bool
-
Refer to
AnimatedList.shrinkWrapfinal
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _DeclarativeListState< T> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited